%%%%%%%%%% start of function snfcn.m %%%%%%%%%%
%
% Function to evalute the equations whose zero will be found 
%     using the bisection method
%
% Written by: Roseanna M. Neupauer
% Modification Date: April 24, 1999
%
% function f=snfcn(beta,u,sn,nearzero,large);
% 
% Inputs
%     beta         estimation of the ith beta 
%     u            ith upper value
%     sn           ith expected value
%     nearzero     value below which the asymptotic 
%                    approximation to zero is used
%     large        value above which the asymptotic 
%                    approximation to infinity
%
% Outputs
%     f            value of function whos zero will be found 
%                    using the bisection method

function f=snfcn(beta,u,sn,nearzero,large);

bu=beta*u;
if bu == 0

     % Equation 3.6
     f=sn-u/2;

elseif (abs(bu) < nearzero) 

     % Equation 3.7
     f=sn-(u*(12.-8.*bu+3.*bu^2)/(24.-12.*bu+4.*bu^2-bu^3));

elseif bu < -large

     % page 56
     f=sn-(u+1/beta);

elseif (bu > large)

     % page 57
     f=sn-1/beta;

else

     % Equation 3.5 and Equation A.12
     f=sn-((exp(-bu).*(-bu-1)+1)/(beta.*(1-exp(-bu))));

end     

return
%%%%%%%%%%  end of function snfcn.m  %%%%%%%%%%
